@@ -50,10 +50,8 @@ class S3Storage(Storage):
         """
         key = source.binary_to_str(value).decode()
         try:
-            data = Binary()
-            self.s3cnx.download_fileobj(self.bucket, key, data)
-            data.seek(0)
-            return data
+            return Binary(self.s3cnx.get_object(
+                Bucket=self.bucket, Key=key)['Body'].read())
         except Exception as ex:
             source.critical("can't retrive S3 object %s: %s", value, ex)
             return None
